/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="html_save_options_data.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// container class for html save options.
class HtmlSaveOptionsData extends SaveOptionsData {
  /// Gets or sets specifies whether negative left and right indents of paragraphs are allowed (not normalized).
  bool allowNegativeIndent;

  /// Gets or sets specifies a prefix which is added to all CSS class names. Default value is an empty string and generated CSS class names have no common prefix.
  /// If this value is not empty, all CSS classes generated by Aspose.Words will start with the specified prefix.This might be useful, for example, if you add custom CSS to generated documents and want to prevent class name conflicts.
  /// If the value is not null or empty, it must be a valid CSS identifier.
  String cssClassNamePrefix;

  /// Gets or sets specifies the name of the CSS file written when the document is exported to HTML.
  String cssStyleSheetFileName;

  /// Gets or sets specifies how CSS styles are exported.
  String cssStyleSheetType;

  /// Gets or sets specifies how the document should be split when saving.
  String documentSplitCriteria;

  /// Gets or sets specifies the maximum level of headings at which to split the document.
  int documentSplitHeadingLevel;

  /// Gets or sets specifies the encoding to use when exporting.
  String encoding;

  /// Gets or sets specifies whether to export built-in and custom document properties.
  bool exportDocumentProperties;

  /// Gets or sets controls how drop-down form fields are saved to HTML.
  /// Default value is false.
  bool exportDropDownFormFieldAsText;

  /// Gets or sets specifies whether font resources should be exported.
  bool exportFontResources;

  /// Gets or sets specifies whether fonts resources should be embedded to HTML in Base64 encoding.  Default is false.
  bool exportFontsAsBase64;

  /// Gets or sets specifies how headers and footers are output.
  String exportHeadersFootersMode;

  /// Gets or sets specifies whether images are saved in Base64 format.
  bool exportImagesAsBase64;

  /// Gets or sets specifies whether language information is exported.
  bool exportLanguageInformation;

  /// Gets or sets controls how list labels are output.
  String exportListLabels;

  /// Gets or sets specifies whether original URL should be used as the URL of the linked images.
  /// Default value is false.
  bool exportOriginalUrlForLinkedImages;

  /// Gets or sets specifies whether page margins is exported to HTML, MHTML or EPUB.
  /// Default is false.
  bool exportPageMargins;

  /// Gets or sets specifies whether page setup is exported.
  bool exportPageSetup;

  /// Gets or sets specifies whether font sizes should be output in relative units when saving.
  bool exportRelativeFontSize;

  /// Gets or sets specifies whether to write the roundtrip information when saving to HTML
  /// Default value is true.
  bool exportRoundtripInformation;

  /// Gets or sets controls how textboxes represented by Aspose.Words.Drawing.Shape are saved to HTML, MHTML or EPUB. Default value is false.
  /// When set to true, exports textboxes as inline "svg" elements. When false, exports as "image" elements.
  bool exportTextBoxAsSvg;

  /// Gets or sets controls how text input form fields are saved.
  bool exportTextInputFormFieldAsText;

  /// Gets or sets specifies whether to write page numbers to table of contents when saving.
  bool exportTocPageNumbers;

  /// Gets or sets specifies whether to write the DOCTYPE declaration when saving.
  bool exportXhtmlTransitional;

  /// Gets or sets controls which font resources need subsetting when saving.
  int fontResourcesSubsettingSizeThreshold;

  /// Gets or sets specifies the physical folder where fonts are saved when exporting a document.
  String fontsFolder;

  /// Gets or sets specifies the name of the folder used to construct font URIs.
  String fontsFolderAlias;

  /// Gets or sets specifies version of HTML standard that should be used when saving the document to HTML or MHTML.
  /// Default value is Aspose.Words.Saving.HtmlVersion.Xhtml.
  HtmlSaveOptionsData_HtmlVersionEnum htmlVersion;

  /// Gets or sets specifies the output resolution for images when exporting.
  int imageResolution;

  /// Gets or sets specifies the physical folder where images are saved when exporting a document.
  String imagesFolder;

  /// Gets or sets specifies the name of the folder used to construct image URIs.
  String imagesFolderAlias;

  /// Gets or sets specifies in what format metafiles are saved when exporting to HTML, MHTML, or EPUB.
  /// Default value is Aspose.Words.Saving.HtmlMetafileFormat.Png, meaning that metafiles are rendered to raster PNG images.
  /// Metafiles are not natively displayed by HTML browsers. By default, Aspose.Words converts WMF and EMF images into PNG files when exporting to HTML.Other options are to convert metafiles to SVG images or to export them as is without conversion.
  /// Some image transforms, in particular image cropping, will not be applied to metafile images if they are exported to HTML without conversion.
  HtmlSaveOptionsData_MetafileFormatEnum metafileFormat;

  /// Gets or sets controls how OfficeMath objects are exported to HTML, MHTML or EPUB.  Default value is HtmlOfficeMathOutputMode.Image.
  HtmlSaveOptionsData_OfficeMathOutputModeEnum officeMathOutputMode;

  /// Gets or sets specifies whether or not use pretty formats output.
  bool prettyFormat;

  /// Gets or sets specifies whether font family names used in the document are resolved and substituted according to FontSettings when being written into HTML-based formats.
  /// default value is false.
  bool resolveFontNames;

  /// Gets or sets specifies a physical folder where all resources like images, fonts, and external CSS are saved when a document is exported to HTML. Default is an empty string.
  String resourceFolder;

  /// Gets or sets specifies the name of the folder used to construct URIs of all resources written into an HTML document.  Default is an empty string.
  String resourceFolderAlias;

  /// Gets or sets specifies whether images are scaled by Aspose.Words to the bounding shape size when exporting.
  bool scaleImageToShapeSize;

  /// Gets or sets controls how table, row and cell widths are exported.
  String tableWidthOutputMode;

  @override
  void deserialize(Map<String, dynamic> json) {
    super.deserialize(json);
    if (json.containsKey('AllowNegativeIndent')) {
      allowNegativeIndent = json['AllowNegativeIndent'];
    } else {
      allowNegativeIndent = null;
    }

    if (json.containsKey('CssClassNamePrefix')) {
      cssClassNamePrefix = json['CssClassNamePrefix'];
    } else {
      cssClassNamePrefix = null;
    }

    if (json.containsKey('CssStyleSheetFileName')) {
      cssStyleSheetFileName = json['CssStyleSheetFileName'];
    } else {
      cssStyleSheetFileName = null;
    }

    if (json.containsKey('CssStyleSheetType')) {
      cssStyleSheetType = json['CssStyleSheetType'];
    } else {
      cssStyleSheetType = null;
    }

    if (json.containsKey('DocumentSplitCriteria')) {
      documentSplitCriteria = json['DocumentSplitCriteria'];
    } else {
      documentSplitCriteria = null;
    }

    if (json.containsKey('DocumentSplitHeadingLevel')) {
      documentSplitHeadingLevel = json['DocumentSplitHeadingLevel'];
    } else {
      documentSplitHeadingLevel = null;
    }

    if (json.containsKey('Encoding')) {
      encoding = json['Encoding'];
    } else {
      encoding = null;
    }

    if (json.containsKey('ExportDocumentProperties')) {
      exportDocumentProperties = json['ExportDocumentProperties'];
    } else {
      exportDocumentProperties = null;
    }

    if (json.containsKey('ExportDropDownFormFieldAsText')) {
      exportDropDownFormFieldAsText = json['ExportDropDownFormFieldAsText'];
    } else {
      exportDropDownFormFieldAsText = null;
    }

    if (json.containsKey('ExportFontResources')) {
      exportFontResources = json['ExportFontResources'];
    } else {
      exportFontResources = null;
    }

    if (json.containsKey('ExportFontsAsBase64')) {
      exportFontsAsBase64 = json['ExportFontsAsBase64'];
    } else {
      exportFontsAsBase64 = null;
    }

    if (json.containsKey('ExportHeadersFootersMode')) {
      exportHeadersFootersMode = json['ExportHeadersFootersMode'];
    } else {
      exportHeadersFootersMode = null;
    }

    if (json.containsKey('ExportImagesAsBase64')) {
      exportImagesAsBase64 = json['ExportImagesAsBase64'];
    } else {
      exportImagesAsBase64 = null;
    }

    if (json.containsKey('ExportLanguageInformation')) {
      exportLanguageInformation = json['ExportLanguageInformation'];
    } else {
      exportLanguageInformation = null;
    }

    if (json.containsKey('ExportListLabels')) {
      exportListLabels = json['ExportListLabels'];
    } else {
      exportListLabels = null;
    }

    if (json.containsKey('ExportOriginalUrlForLinkedImages')) {
      exportOriginalUrlForLinkedImages = json['ExportOriginalUrlForLinkedImages'];
    } else {
      exportOriginalUrlForLinkedImages = null;
    }

    if (json.containsKey('ExportPageMargins')) {
      exportPageMargins = json['ExportPageMargins'];
    } else {
      exportPageMargins = null;
    }

    if (json.containsKey('ExportPageSetup')) {
      exportPageSetup = json['ExportPageSetup'];
    } else {
      exportPageSetup = null;
    }

    if (json.containsKey('ExportRelativeFontSize')) {
      exportRelativeFontSize = json['ExportRelativeFontSize'];
    } else {
      exportRelativeFontSize = null;
    }

    if (json.containsKey('ExportRoundtripInformation')) {
      exportRoundtripInformation = json['ExportRoundtripInformation'];
    } else {
      exportRoundtripInformation = null;
    }

    if (json.containsKey('ExportTextBoxAsSvg')) {
      exportTextBoxAsSvg = json['ExportTextBoxAsSvg'];
    } else {
      exportTextBoxAsSvg = null;
    }

    if (json.containsKey('ExportTextInputFormFieldAsText')) {
      exportTextInputFormFieldAsText = json['ExportTextInputFormFieldAsText'];
    } else {
      exportTextInputFormFieldAsText = null;
    }

    if (json.containsKey('ExportTocPageNumbers')) {
      exportTocPageNumbers = json['ExportTocPageNumbers'];
    } else {
      exportTocPageNumbers = null;
    }

    if (json.containsKey('ExportXhtmlTransitional')) {
      exportXhtmlTransitional = json['ExportXhtmlTransitional'];
    } else {
      exportXhtmlTransitional = null;
    }

    if (json.containsKey('FontResourcesSubsettingSizeThreshold')) {
      fontResourcesSubsettingSizeThreshold = json['FontResourcesSubsettingSizeThreshold'];
    } else {
      fontResourcesSubsettingSizeThreshold = null;
    }

    if (json.containsKey('FontsFolder')) {
      fontsFolder = json['FontsFolder'];
    } else {
      fontsFolder = null;
    }

    if (json.containsKey('FontsFolderAlias')) {
      fontsFolderAlias = json['FontsFolderAlias'];
    } else {
      fontsFolderAlias = null;
    }

    if (json.containsKey('HtmlVersion')) {
      switch (json['HtmlVersion']) {
        case 'Xhtml': htmlVersion = HtmlSaveOptionsData_HtmlVersionEnum.xhtml; break;
        case 'Html5': htmlVersion = HtmlSaveOptionsData_HtmlVersionEnum.html5; break;
        default: htmlVersion = null; break;
      }
    } else {
      htmlVersion = null;
    }

    if (json.containsKey('ImageResolution')) {
      imageResolution = json['ImageResolution'];
    } else {
      imageResolution = null;
    }

    if (json.containsKey('ImagesFolder')) {
      imagesFolder = json['ImagesFolder'];
    } else {
      imagesFolder = null;
    }

    if (json.containsKey('ImagesFolderAlias')) {
      imagesFolderAlias = json['ImagesFolderAlias'];
    } else {
      imagesFolderAlias = null;
    }

    if (json.containsKey('MetafileFormat')) {
      switch (json['MetafileFormat']) {
        case 'Png': metafileFormat = HtmlSaveOptionsData_MetafileFormatEnum.png; break;
        case 'Svg': metafileFormat = HtmlSaveOptionsData_MetafileFormatEnum.svg; break;
        case 'EmfOrWmf': metafileFormat = HtmlSaveOptionsData_MetafileFormatEnum.emfOrWmf; break;
        default: metafileFormat = null; break;
      }
    } else {
      metafileFormat = null;
    }

    if (json.containsKey('OfficeMathOutputMode')) {
      switch (json['OfficeMathOutputMode']) {
        case 'Image': officeMathOutputMode = HtmlSaveOptionsData_OfficeMathOutputModeEnum.image; break;
        case 'MathML': officeMathOutputMode = HtmlSaveOptionsData_OfficeMathOutputModeEnum.mathML; break;
        case 'Text': officeMathOutputMode = HtmlSaveOptionsData_OfficeMathOutputModeEnum.text; break;
        default: officeMathOutputMode = null; break;
      }
    } else {
      officeMathOutputMode = null;
    }

    if (json.containsKey('PrettyFormat')) {
      prettyFormat = json['PrettyFormat'];
    } else {
      prettyFormat = null;
    }

    if (json.containsKey('ResolveFontNames')) {
      resolveFontNames = json['ResolveFontNames'];
    } else {
      resolveFontNames = null;
    }

    if (json.containsKey('ResourceFolder')) {
      resourceFolder = json['ResourceFolder'];
    } else {
      resourceFolder = null;
    }

    if (json.containsKey('ResourceFolderAlias')) {
      resourceFolderAlias = json['ResourceFolderAlias'];
    } else {
      resourceFolderAlias = null;
    }

    if (json.containsKey('ScaleImageToShapeSize')) {
      scaleImageToShapeSize = json['ScaleImageToShapeSize'];
    } else {
      scaleImageToShapeSize = null;
    }

    if (json.containsKey('TableWidthOutputMode')) {
      tableWidthOutputMode = json['TableWidthOutputMode'];
    } else {
      tableWidthOutputMode = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    _result.addAll(super.serialize());
    if (allowNegativeIndent != null) {
      _result['AllowNegativeIndent'] = allowNegativeIndent;
    }

    if (cssClassNamePrefix != null) {
      _result['CssClassNamePrefix'] = cssClassNamePrefix;
    }

    if (cssStyleSheetFileName != null) {
      _result['CssStyleSheetFileName'] = cssStyleSheetFileName;
    }

    if (cssStyleSheetType != null) {
      _result['CssStyleSheetType'] = cssStyleSheetType;
    }

    if (documentSplitCriteria != null) {
      _result['DocumentSplitCriteria'] = documentSplitCriteria;
    }

    if (documentSplitHeadingLevel != null) {
      _result['DocumentSplitHeadingLevel'] = documentSplitHeadingLevel;
    }

    if (encoding != null) {
      _result['Encoding'] = encoding;
    }

    if (exportDocumentProperties != null) {
      _result['ExportDocumentProperties'] = exportDocumentProperties;
    }

    if (exportDropDownFormFieldAsText != null) {
      _result['ExportDropDownFormFieldAsText'] = exportDropDownFormFieldAsText;
    }

    if (exportFontResources != null) {
      _result['ExportFontResources'] = exportFontResources;
    }

    if (exportFontsAsBase64 != null) {
      _result['ExportFontsAsBase64'] = exportFontsAsBase64;
    }

    if (exportHeadersFootersMode != null) {
      _result['ExportHeadersFootersMode'] = exportHeadersFootersMode;
    }

    if (exportImagesAsBase64 != null) {
      _result['ExportImagesAsBase64'] = exportImagesAsBase64;
    }

    if (exportLanguageInformation != null) {
      _result['ExportLanguageInformation'] = exportLanguageInformation;
    }

    if (exportListLabels != null) {
      _result['ExportListLabels'] = exportListLabels;
    }

    if (exportOriginalUrlForLinkedImages != null) {
      _result['ExportOriginalUrlForLinkedImages'] = exportOriginalUrlForLinkedImages;
    }

    if (exportPageMargins != null) {
      _result['ExportPageMargins'] = exportPageMargins;
    }

    if (exportPageSetup != null) {
      _result['ExportPageSetup'] = exportPageSetup;
    }

    if (exportRelativeFontSize != null) {
      _result['ExportRelativeFontSize'] = exportRelativeFontSize;
    }

    if (exportRoundtripInformation != null) {
      _result['ExportRoundtripInformation'] = exportRoundtripInformation;
    }

    if (exportTextBoxAsSvg != null) {
      _result['ExportTextBoxAsSvg'] = exportTextBoxAsSvg;
    }

    if (exportTextInputFormFieldAsText != null) {
      _result['ExportTextInputFormFieldAsText'] = exportTextInputFormFieldAsText;
    }

    if (exportTocPageNumbers != null) {
      _result['ExportTocPageNumbers'] = exportTocPageNumbers;
    }

    if (exportXhtmlTransitional != null) {
      _result['ExportXhtmlTransitional'] = exportXhtmlTransitional;
    }

    if (fontResourcesSubsettingSizeThreshold != null) {
      _result['FontResourcesSubsettingSizeThreshold'] = fontResourcesSubsettingSizeThreshold;
    }

    if (fontsFolder != null) {
      _result['FontsFolder'] = fontsFolder;
    }

    if (fontsFolderAlias != null) {
      _result['FontsFolderAlias'] = fontsFolderAlias;
    }

    if (htmlVersion != null) {
      switch (htmlVersion) {
        case HtmlSaveOptionsData_HtmlVersionEnum.xhtml: _result['HtmlVersion'] = 'Xhtml'; break;
        case HtmlSaveOptionsData_HtmlVersionEnum.html5: _result['HtmlVersion'] = 'Html5'; break;
        default: break;
      }
    }

    if (imageResolution != null) {
      _result['ImageResolution'] = imageResolution;
    }

    if (imagesFolder != null) {
      _result['ImagesFolder'] = imagesFolder;
    }

    if (imagesFolderAlias != null) {
      _result['ImagesFolderAlias'] = imagesFolderAlias;
    }

    if (metafileFormat != null) {
      switch (metafileFormat) {
        case HtmlSaveOptionsData_MetafileFormatEnum.png: _result['MetafileFormat'] = 'Png'; break;
        case HtmlSaveOptionsData_MetafileFormatEnum.svg: _result['MetafileFormat'] = 'Svg'; break;
        case HtmlSaveOptionsData_MetafileFormatEnum.emfOrWmf: _result['MetafileFormat'] = 'EmfOrWmf'; break;
        default: break;
      }
    }

    if (officeMathOutputMode != null) {
      switch (officeMathOutputMode) {
        case HtmlSaveOptionsData_OfficeMathOutputModeEnum.image: _result['OfficeMathOutputMode'] = 'Image'; break;
        case HtmlSaveOptionsData_OfficeMathOutputModeEnum.mathML: _result['OfficeMathOutputMode'] = 'MathML'; break;
        case HtmlSaveOptionsData_OfficeMathOutputModeEnum.text: _result['OfficeMathOutputMode'] = 'Text'; break;
        default: break;
      }
    }

    if (prettyFormat != null) {
      _result['PrettyFormat'] = prettyFormat;
    }

    if (resolveFontNames != null) {
      _result['ResolveFontNames'] = resolveFontNames;
    }

    if (resourceFolder != null) {
      _result['ResourceFolder'] = resourceFolder;
    }

    if (resourceFolderAlias != null) {
      _result['ResourceFolderAlias'] = resourceFolderAlias;
    }

    if (scaleImageToShapeSize != null) {
      _result['ScaleImageToShapeSize'] = scaleImageToShapeSize;
    }

    if (tableWidthOutputMode != null) {
      _result['TableWidthOutputMode'] = tableWidthOutputMode;
    }
    return _result;
  }
}

/// Gets or sets specifies version of HTML standard that should be used when saving the document to HTML or MHTML.
/// Default value is Aspose.Words.Saving.HtmlVersion.Xhtml.
enum HtmlSaveOptionsData_HtmlVersionEnum
{ 
  xhtml,
  html5
}

/// Gets or sets specifies in what format metafiles are saved when exporting to HTML, MHTML, or EPUB.
/// Default value is Aspose.Words.Saving.HtmlMetafileFormat.Png, meaning that metafiles are rendered to raster PNG images.
/// Metafiles are not natively displayed by HTML browsers. By default, Aspose.Words converts WMF and EMF images into PNG files when exporting to HTML.Other options are to convert metafiles to SVG images or to export them as is without conversion.
/// Some image transforms, in particular image cropping, will not be applied to metafile images if they are exported to HTML without conversion.
enum HtmlSaveOptionsData_MetafileFormatEnum
{ 
  png,
  svg,
  emfOrWmf
}

/// Gets or sets controls how OfficeMath objects are exported to HTML, MHTML or EPUB.  Default value is HtmlOfficeMathOutputMode.Image.
enum HtmlSaveOptionsData_OfficeMathOutputModeEnum
{ 
  image,
  mathML,
  text
}

